@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KLDAP_LDAPOBJECT_H
-#define KLDAP_LDAPOBJECT_H
+#pragma once
 
 #include <QList>
 #include <QMap>
@@ -21,8 +20,8 @@ class LdapObjectPrivate;
 
 namespace KLDAP
 {
-typedef QList<QByteArray> LdapAttrValue;
-typedef QMap<QString, LdapAttrValue> LdapAttrMap;
+using LdapAttrValue = QList<QByteArray>;
+using LdapAttrMap = QMap<QString, LdapAttrValue>;
 
 /**
  * @brief
@@ -99,7 +98,5 @@ private:
     QSharedDataPointer<LdapObjectPrivate> d;
 };
 
-typedef QVector<LdapObject> LdapObjects;
+using LdapObjects = QVector<LdapObject>;
 }
-
-#endif
