@@ -119,7 +119,8 @@ void LdapSearchPrivate::result()
             }
             qCDebug(LDAP_LOG) << " estimated size:" << estsize;
             if (estsize != -1 && !cookie.isEmpty()) {
-                LdapControls ctrls, savedctrls;
+                LdapControls ctrls;
+                LdapControls savedctrls;
                 savedctrls = mOp.serverControls();
                 ctrls = savedctrls;
                 LdapControl::insert(ctrls, LdapControl::createPageControl(mPageSize, cookie));
@@ -252,7 +253,6 @@ LdapSearch::LdapSearch(LdapConnection &connection)
 LdapSearch::~LdapSearch()
 {
     d->closeConnection();
-    delete d;
 }
 
 void LdapSearch::setConnection(LdapConnection &connection)
