@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -9,20 +9,20 @@
 #include <kldap/ldapserver.h>
 
 #include <KConfig>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <qt5keychain/keychain.h>
+#else
+#include <qt6keychain/keychain.h>
+#endif
 using namespace QKeychain;
 using namespace KLDAP;
 
 class Q_DECL_HIDDEN LdapClientSearchConfig::LdapClientSearchConfigPrivate
 {
 public:
-    LdapClientSearchConfigPrivate()
-    {
-    }
+    LdapClientSearchConfigPrivate() = default;
 
-    ~LdapClientSearchConfigPrivate()
-    {
-    }
+    ~LdapClientSearchConfigPrivate() = default;
 };
 
 Q_GLOBAL_STATIC_WITH_ARGS(KConfig, s_config, (QLatin1String("kabldaprc"), KConfig::NoGlobals))
