@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -9,7 +9,11 @@
 
 #include <KConfig>
 #include <kldap/ldapdn.h>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <qt5keychain/keychain.h>
+#else
+#include <qt6keychain/keychain.h>
+#endif
 using namespace QKeychain;
 
 using namespace KLDAP;
@@ -18,9 +22,7 @@ LdapClientSearchConfigWriteConfigJob::LdapClientSearchConfigWriteConfigJob(QObje
 {
 }
 
-LdapClientSearchConfigWriteConfigJob::~LdapClientSearchConfigWriteConfigJob()
-{
-}
+LdapClientSearchConfigWriteConfigJob::~LdapClientSearchConfigWriteConfigJob() = default;
 
 bool LdapClientSearchConfigWriteConfigJob::canStart() const
 {
